@@ -15,7 +15,7 @@ our @ISA = qw(DynaLoader);
 # SQL_DRIVER_VER is formatted as dd.dd.dddd
 # for version 5.x please switch to 5.00(_00) version numbering
 # keep $VERSION in Bundle/DBD/mysql.pm in sync
-our $VERSION = '4.041_02';
+our $VERSION = '4.045';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -169,19 +169,17 @@ sub connect {
 sub data_sources {
     my($self) = shift;
     my($attributes) = shift;
-    my($host, $port, $user, $password, $utf8) = ('', '', '', '');
+    my($host, $port, $user, $password) = ('', '', '', '');
     if ($attributes) {
       $host = $attributes->{host} || '';
       $port = $attributes->{port} || '';
       $user = $attributes->{user} || '';
       $password = $attributes->{password} || '';
-      $utf8 = $attributes->{utf8} || $attributes->{mysql_enable_utf8};
     }
-    my(@dsn) = $self->func($host, $port, $user, $password, $utf8, '_ListDBs');
-    $utf8 = $utf8 ? ";mysql_enable_utf8=1" : "";
+    my(@dsn) = $self->func($host, $port, $user, $password, '_ListDBs');
     my($i);
     for ($i = 0;  $i < @dsn;  $i++) {
-	$dsn[$i] = "DBI:mysql:$dsn[$i]$utf8";
+	$dsn[$i] = "DBI:mysql:$dsn[$i]";
     }
     @dsn;
 }
@@ -929,12 +927,8 @@ DBD::mysql - MySQL driver for the Perl5 Database Interface (DBI)
 
   # Drop table 'foo'. This may fail, if 'foo' doesn't exist
   # Thus we put an eval around it.
-  eval {
-      $dbh->do("DROP TABLE foo");
-      1;
-  } or do {
-      print "Dropping foo failed: $@\n";
-  };
+  eval { $dbh->do("DROP TABLE foo") };
+  print "Dropping foo failed: $@\n" if $@;
 
   # Create a new table 'foo'. This must not fail, thus we don't
   # catch errors.
@@ -1166,9 +1160,13 @@ location for the socket than that built into the client.
 =item mysql_ssl
 
 A true value turns on the CLIENT_SSL flag when connecting to the MySQL
-database:
+server and enforce SSL encryption.  A false value (which is default)
+disable SSL encryption with the MySQL server.
 
-  mysql_ssl=1
+When enabling SSL encryption you should set also other SSL options,
+at least mysql_ssl_ca_file or mysql_ssl_ca_path.
+
+  mysql_ssl=1 mysql_ssl_verify_server_cert=1 mysql_ssl_ca_file=/path/to/ca_cert.pem
 
 This means that your communication with the server will be encrypted.
 
@@ -1176,21 +1174,71 @@ Please note that this can only work if you enabled SSL when compiling
 DBD::mysql; this is the default starting version 4.034.
 See L<DBD::mysql::INSTALL> for more details.
 
-If you turn mysql_ssl on, you might also wish to use the following
-flags:
-
-=item mysql_ssl_client_key
-
-=item mysql_ssl_client_cert
-
 =item mysql_ssl_ca_file
 
+The path to a file in PEM format that contains a list of trusted SSL
+certificate authorities.
+
+When set MySQL server certificate is checked that it is signed by some
+CA certificate in the list.  Common Name value is not verified unless
+C<mysql_ssl_verify_server_cert> is enabled.
+
 =item mysql_ssl_ca_path
 
+The path to a directory that contains trusted SSL certificate authority
+certificates in PEM format.
+
+When set MySQL server certificate is checked that it is signed by some
+CA certificate in the list.  Common Name value is not verified unless
+C<mysql_ssl_verify_server_cert> is enabled.
+
+Please note that this option is supported only if your MySQL client was
+compiled with OpenSSL library, and not with default yaSSL library.
+
+=item mysql_ssl_verify_server_cert
+
+Checks the server's Common Name value in the certificate that the server
+sends to the client.  The client verifies that name against the host name
+the client uses for connecting to the server, and the connection fails if
+there is a mismatch.  For encrypted connections, this option helps prevent
+man-in-the-middle attacks.
+
+Verification of the host name is disabled by default.
+
+=item mysql_ssl_client_key
+
+The name of the SSL key file in PEM format to use for establishing
+a secure connection.
+
+=item mysql_ssl_client_cert
+
+The name of the SSL certificate file in PEM format to use for
+establishing a secure connection.
+
 =item mysql_ssl_cipher
 
-These are used to specify the respective parameters of a call
-to mysql_ssl_set, if mysql_ssl is turned on.
+A list of permissible ciphers to use for connection encryption.  If no
+cipher in the list is supported, encrypted connections will not work.
+
+  mysql_ssl_cipher=AES128-SHA
+  mysql_ssl_cipher=DHE-RSA-AES256-SHA:AES128-SHA
+
+=item mysql_ssl_optional
+
+Setting C<mysql_ssl_optional> to true disables strict SSL enforcement
+and makes SSL connection optional.  This option opens security hole
+for man-in-the-middle attacks.  Default value is false which means
+that C<mysql_ssl> set to true enforce SSL encryption.
+
+This option was introduced in 4.043 version of DBD::mysql.  Due to
+L<The BACKRONYM|http://backronym.fail/> and L<The Riddle|http://riddle.link/>
+vulnerabilities in libmysqlclient library, enforcement of SSL
+encryption was not possbile and therefore C<mysql_ssl_optional=1>
+was effectively set for all DBD::mysql versions prior to 4.043.
+Starting with 4.043, DBD::mysql with C<mysql_ssl=1> could refuse
+connection to MySQL server if underlaying libmysqlclient library is
+vulnerable.  Option C<mysql_ssl_optional> can be used to make SSL
+connection vulnerable.
 
 
 =item mysql_local_infile
@@ -1380,10 +1428,6 @@ method.  Instead, you should use the portable method
 
     @dbs = DBI->data_sources("mysql");
 
-or with connection arguments
-
-    @dbs = DBI->data_sources("mysql", {"host" => $host, "port" => $port, "user" => $user, "password" => $pass, "utf8" => 1});
-
 =back
 
 
@@ -1506,71 +1550,25 @@ See L</"STATEMENT HANDLES">.
 
 =item mysql_enable_utf8
 
-This attribute affects input data from DBI (statement and bind parameters) and
-output data from the MySQL server.  Applies also for database, table and column
-names and also for warning and error messages from MySQL server.
+This attribute determines whether DBD::mysql should assume strings
+stored in the database are utf8.  This feature defaults to off.
 
-If used as a part of the call to C<connect()> then it issues the command
-C<SET NAMES utf8>.
-
-When set, any statement or bind parameter which is not of binary type is
-automatically encoded to UTF-8 octets before being sent to the MySQL server.
-Any retrieved MySQL data with a charset of C<utf8> or C<utf8mb4> from a textual
-column type (char, varchar, etc) is automatically UTF-8 decoded and returned as
-a perl Unicode scalar (with SvUTF8 flag on).  That enables character semantics
-on those retrieved UTF-8 strings.  The MySQL charset of a retrieved value is
-affected by the last C<SET NAMES> command and also could be affected by the
-database, table and column configuration.  For more information, see the
-I<Character Set Support> chapter in the MySQL manual:
+When set, a data retrieved from a textual column type (char, varchar,
+etc) will have the UTF-8 flag turned on if necessary.  This enables
+character semantics on that string.  You will also need to ensure that
+your database / table / column is configured to use UTF8. See for more
+information the chapter on character set support in the MySQL manual:
 L<http://dev.mysql.com/doc/refman/5.7/en/charset.html>
 
-When unset and a statement or bind parameter contains a wide Unicode character then
-DBD::mysql gives the warning C<Wide character in ... but mysql_enable_utf8 not set>.
-The MySQL protocol does not support wide characters and so DBD::mysql does not know
-how to send a statement with wide characters when C<mysql_enable_utf8> is not set.
-
-Please note that when C<mysql_enable_utf8> is set, the input statement and bind
-parameters are encoded to UTF-8 octets even if the current MySQL session charset
-is not C<utf8> or C<utf8mb4>!  You are responsible for calling the C<SET NAMES utf8>
-or C<SET NAMES utf8mb4> command when setting the C<mysql_enable_utf8> attribute
-B<after> connecting.  The same applies to unsetting the C<mysql_enable_utf8>
-attribute.  You are responsible for calling C<SET NAMES latin1> (resp. with
-correct charset) and then passing perl scalars in the correct encoding.
-Otherwise strings will be sent to MySQL server incorrectly!
-
-Input bind parameters of binary types (C<SQL_BIT>, C<SQL_BLOB>, C<SQL_BINARY>,
-C<SQL_VARBINARY> and C<SQL_LONGVARBINARY>) are not touched regardless of the
-C<mysql_enable_utf8> attribute state.  They are treated as a sequence of octets
-and sent to the MySQL server as is.  If that bind parameter contains a wide Unicode
-character then DBD::mysql gives the warning C<Wide character in binary field ...>
-because binary data is a sequence of octets, not Unicode characters!
-
-Output data fetched from the MySQL server which does not have a C<utf8> or
-C<utf8mb4> charset (so also binary data) is not UTF-8 decoded regardless of the
-C<mysql_enable_utf8> attribute state.  They are treated as a sequence of octets
-and it is your responsibility to decode them correctly.
-
-B<WARNING>: DBD::mysql prior to version 4.042 had different and buggy behaviour
-when the attribute C<mysql_enable_utf8> was enabled!  Input statement and bind
-parameters were never encoded to UTF-8 octets and retrieved columns were
-always UTF-8 decoded regardless of the column charset (except binary charsets).
+Additionally, turning on this flag tells MySQL that incoming data should
+be treated as UTF-8.  This will only take effect if used as part of the
+call to connect().  If you turn the flag on after connecting, you will
+need to issue the command C<SET NAMES utf8> to get the same effect.
 
 =item mysql_enable_utf8mb4
 
-Exactly the same as the attribute C<mysql_enable_utf8>.
-
-Additionally if used as a part of the call to C<connect()> then it issues
-the command C<SET NAMES utf8mb4> instead of C<utf8>.
-
-MySQL's C<utf8mb4> charset is capable of handling 4-byte UTF-8 characters.
-MySQL's C<utf8> charset is capable of handling only up to 3-byte UTF-8
-characters!  See MySQL manual for more information:
-L<http://dev.mysql.com/doc/refman/5.7/en/charset-unicode-utf8mb4.html>
-
-You should use MySQL's C<utf8mb4> charset instead of C<utf8> to prevent problems
-with data exchange.  When the C<utf8> charset is used then you are responsible
-for 3-byte UTF-8 sequence checks on input perl scalar strings.  Otherwise MySQL
-server can reject or modify the input statement!
+This is similar to mysql_enable_utf8, but is capable of handling 4-byte
+UTF-8 characters.
 
 =item mysql_bind_type_guessing
 
